@@ -1,4 +1,4 @@
-%# Copyright (C) 2006-2011, Thomas Treichl <treichl@users.sourceforge.net>
+%# Copyright (C) 2006-2012, Thomas Treichl <treichl@users.sourceforge.net>
 %# OdePkg - A package for solving ordinary differential equations and more
 %#
 %# This program is free software; you can redistribute it and/or modify
@@ -223,7 +223,7 @@ function [varargout] = ode23 (vfun, vslot, vinit, varargin)
 
   %# Implementation of the option Mass has been finished. This option
   %# can be set by the user to another value than default value.
-  if (~isempty (vodeoptions.Mass) && ismatrix (vodeoptions.Mass))
+  if (~isempty (vodeoptions.Mass) && isnumeric (vodeoptions.Mass))
     vhavemasshandle = false; vmass = vodeoptions.Mass; %# constant mass
   elseif (isa (vodeoptions.Mass, 'function_handle'))
     vhavemasshandle = true; %# mass defined by a function handle
