@@ -1,4 +1,4 @@
-%# Copyright (C) 2006-2011, Thomas Treichl <treichl@users.sourceforge.net>
+%# Copyright (C) 2006-2012, Thomas Treichl <treichl@users.sourceforge.net>
 %# OdePkg - A package for solving ordinary differential equations and more
 %#
 %# This program is free software; you can redistribute it and/or modify
@@ -72,7 +72,7 @@ function [] = odepkg_validate_ccfiles ()
 
   for vcnt=1:length(vfile)
     printf ('Testing function %s ... ', vsolv{vcnt});
-    autoload (vsolv{vcnt}, canonicalize_file_name ('dldsolver.oct'));
+    autoload (vsolv{vcnt}, which ('dldsolver.oct'));
     test (vfile{vcnt}, 'quiet'); fflush (1);
   end
 
