@@ -1,4 +1,4 @@
-%# Copyright (C) 2006-2011, Thomas Treichl <treichl@users.sourceforge.net>
+%# Copyright (C) 2006-2012, Thomas Treichl <treichl@users.sourceforge.net>
 %# OdePkg - A package for solving ordinary differential equations and more
 %#
 %# This program is free software; you can redistribute it and/or modify
@@ -186,7 +186,7 @@ function [vret] = odepkg_structure_check (varargin)
 
       case 'Jacobian'
         if (isempty (vret.(vfld{vcntarg})) || ...
-            ismatrix (vret.(vfld{vcntarg})) || ...
+            isnumeric (vret.(vfld{vcntarg})) || ...
             isa (vret.(vfld{vcntarg}), 'function_handle') || ...
             iscell (vret.(vfld{vcntarg})))
         else
@@ -198,7 +198,7 @@ function [vret] = odepkg_structure_check (varargin)
       case 'JPattern'
         if (isempty (vret.(vfld{vcntarg})) || ...
             isvector (vret.(vfld{vcntarg})) || ...
-            ismatrix (vret.(vfld{vcntarg})))
+            isnumeric (vret.(vfld{vcntarg})))
         else
           error ('OdePkg:InvalidParameter', ...
             'Unknown parameter name "%s" or no valid parameter value', ...
@@ -216,7 +216,7 @@ function [vret] = odepkg_structure_check (varargin)
 
       case 'Mass'
         if (isempty (vret.(vfld{vcntarg})) || ...
-            ismatrix (vret.(vfld{vcntarg})) || ...
+            isnumeric (vret.(vfld{vcntarg})) || ...
             isa (vret.(vfld{vcntarg}), 'function_handle'))
         else
           error ('OdePkg:InvalidParameter', ...
@@ -237,7 +237,7 @@ function [vret] = odepkg_structure_check (varargin)
       case 'MvPattern'
         if (isempty (vret.(vfld{vcntarg})) || ...
             isvector (vret.(vfld{vcntarg})) || ...
-            ismatrix (vret.(vfld{vcntarg})))
+            isnumeric (vret.(vfld{vcntarg})))
         else
           error ('OdePkg:InvalidParameter', ...
             'Unknown parameter name "%s" or no valid parameter value', ...
