@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2009, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2012, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -25,9 +25,9 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 /* -*- texinfo -*-
  * @subsection Source file @file{odepkg_auxiliary_functions.cc}
  *
- * @deftypefn {Function} octave_value odepkg_auxiliary_getmapvalue (std::string vnam, Octave_map vmap)
+ * @deftypefn {Function} octave_value odepkg_auxiliary_getmapvalue (std::string vnam, octave_scalar_map vmap)
  *
- * Return the @code{octave_value} from the field that is identified by the string @var{vnam} of the @code{Octave_map} that is given by @var{vmap}. The input arguments of this function are
+ * Return the @code{octave_value} from the field that is identified by the string @var{vnam} of the @code{octave_scalar_map} that is given by @var{vmap}. The input arguments of this function are
  *
  * @itemize @minus
  * @item @var{vnam}: The name of the field whose value is returned
@@ -35,11 +35,6 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
  * @end itemize
  * @end deftypefn
  */
-octave_value odepkg_auxiliary_getmapvalue (std::string vnam, Octave_map vmap) {
-  Octave_map::const_iterator viter;
-  viter = vmap.seek (vnam);
-  return (vmap.contents(viter)(0));
-}
 
 /* -*- texinfo -*-
  * @deftypefn {Function} octave_idx_type odepkg_auxiliary_isvector (octave_value vval)
@@ -371,7 +366,7 @@ octave_value odepkg_auxiliary_evalmassode
 octave_value odepkg_auxiliary_makestats
   (octave_value_list vstats, octave_idx_type vprnt) {
 
-  Octave_map vretval;
+  octave_scalar_map vretval;
 
   if (vstats.length () < 5)
     error_with_id ("OdePkg:InvalidArgument",
@@ -454,8 +449,8 @@ octave_idx_type odepkg_auxiliary_solstore
       // eg. if the code should be debuged or something like this
       vt = octave_value (vtstore);
       vy = octave_value (vystore);
-      vt.print_with_name (octave_stdout, "vt", true);
-      vy.print_with_name (octave_stdout, "vy", true);
+      vt.print_with_name (octave_stdout, "vt");
+      vy.print_with_name (octave_stdout, "vy");
       break;
   }
 
