@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2008, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2012, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -350,7 +350,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   octave_idx_type nargin = args.length (); // The number of input arguments
   octave_value_list vretval;               // The cell array of return args
-  Octave_map vodeopt;                      // The OdePkg options structure
+  octave_scalar_map vodeopt;                      // The OdePkg options structure
 
   // Check number and types of all the input arguments
   if (nargin < 4) {
@@ -408,7 +408,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
     // Fifth input argument != OdePkg option, need a default structure
     if (!args(4).is_map ()) {
       octave_value_list tmp = feval ("odeset", tmp, 1);
-      vodeopt = tmp(0).map_value ();        // Create a default structure
+      vodeopt = tmp(0).scalar_map_value ();        // Create a default structure
       for (octave_idx_type vcnt = 4; vcnt < nargin; vcnt++)
         vmebdfiextarg(vcnt-4) = args(vcnt); // Save arguments in vmebdfiextarg
     }
@@ -419,7 +419,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
       varin(0) = args(4); varin(1) = "odebdi";
       octave_value_list tmp = feval ("odepkg_structure_check", varin, 1);
       if (error_state) return (vretval);
-      vodeopt = tmp(0).map_value ();        // Create structure of args(4)
+      vodeopt = tmp(0).scalar_map_value ();        // Create structure of args(4)
       for (octave_idx_type vcnt = 5; vcnt < nargin; vcnt++)
         vmebdfiextarg(vcnt-5) = args(vcnt); // Save extra arguments
     }
@@ -430,14 +430,14 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
       varin(0) = args(4); varin(1) = "odebdi"; // Check structure
       octave_value_list tmp = feval ("odepkg_structure_check", varin, 1);
       if (error_state) return (vretval);
-      vodeopt = tmp(0).map_value (); // Create a default structure
+      vodeopt = tmp(0).scalar_map_value (); // Create a default structure
     }
 
   } // if (nargin >= 5)
 
   else { // if nargin == 4, everything else has been checked before
     octave_value_list tmp = feval ("odeset", tmp, 1);
-    vodeopt = tmp(0).map_value (); // Create a default structure
+    vodeopt = tmp(0).scalar_map_value (); // Create a default structure
   }
 
 /* Start PREPROCESSING, ie. check which options have been set and
@@ -447,7 +447,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   // Implementation of the option RelTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vreltol = odepkg_auxiliary_getmapvalue ("RelTol", vodeopt);
+  octave_value vreltol = vodeopt.contents ("RelTol");
   if (vreltol.is_empty ()) {
     vreltol = 1.0e-6;
     warning_with_id ("OdePkg:InvalidOption", 
@@ -464,7 +464,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   // Implementation of the option AbsTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vabstol = odepkg_auxiliary_getmapvalue ("AbsTol", vodeopt);
+  octave_value vabstol = vodeopt.contents ("AbsTol");
   if (vabstol.is_empty ()) {
     vabstol = 1.0e-6;
     warning_with_id ("OdePkg:InvalidOption", 
@@ -489,41 +489,42 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
-  if (!vnorm.is_empty () && (vnorm.string_value ().compare ("off") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"NormControl\" will be ignored by this solver");
+  octave_value vnorm = vodeopt.contents ("NormControl");
+  if (!vnorm.is_empty ())
+    if (vnorm.string_value ().compare ("off") != 0)
+      warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"NormControl\" will be ignored by this solver");
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vnneg = odepkg_auxiliary_getmapvalue ("NonNegative", vodeopt);
+  octave_value vnneg = vodeopt.contents ("NonNegative");
   if (!vnneg.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
       "Option \"NonNegative\" will be ignored by this solver");
 
   // Implementation of the option OutputFcn has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vplot = odepkg_auxiliary_getmapvalue ("OutputFcn", vodeopt);
+  octave_value vplot = vodeopt.contents ("OutputFcn");
   if (vplot.is_empty () && nargout == 0) vplot = "odeplot";
 
   // Implementation of the option OutputSel has been finished, this
   // option can be set by the user to another value than default value
-  octave_value voutsel = odepkg_auxiliary_getmapvalue ("OutputSel", vodeopt);
+  octave_value voutsel = vodeopt.contents ("OutputSel");
 
   // The option Refine will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vrefine = odepkg_auxiliary_getmapvalue ("Refine", vodeopt);
+  octave_value vrefine = vodeopt.contents ("Refine");
   if (vrefine.int_value () != 0)
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"Refine\" will be ignored by this solver");
 
   // Implementation of the option Stats has been finished, this option
   // can be set by the user to another value than default value
-  octave_value vstats = odepkg_auxiliary_getmapvalue ("Stats", vodeopt);
+  octave_value vstats = vodeopt.contents ("Stats");
 
   // Implementation of the option InitialStep has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vinitstep = odepkg_auxiliary_getmapvalue ("InitialStep", vodeopt);
+  octave_value vinitstep = vodeopt.contents ("InitialStep");
   if (args(1).length () > 2) {
     if (!vinitstep.is_empty ())
       warning_with_id ("OdePkg:InvalidOption",
@@ -539,7 +540,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   // Implementation of the option MaxStep has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vmaxstep = odepkg_auxiliary_getmapvalue ("MaxStep", vodeopt);
+  octave_value vmaxstep = vodeopt.contents ("MaxStep");
   if (vmaxstep.is_empty () && args(1).length () == 2) {
     vmaxstep = (args(1).vector_value ()(1) - args(1).vector_value ()(0)) / 12.5;
     warning_with_id ("OdePkg:InvalidOption", 
@@ -550,11 +551,11 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // Implementation of the option Events has been finished, this
   // option can be set by the user to another value than default
   // value, odepkg_structure_check already checks for a valid value
-  octave_value vevents = odepkg_auxiliary_getmapvalue ("Events", vodeopt);
+  octave_value vevents = vodeopt.contents ("Events");
   octave_value_list veveres; // We save the results of Events here
 
   // The options 'Jacobian', 'JPattern' and 'Vectorized'
-  octave_value vjac = odepkg_auxiliary_getmapvalue ("Jacobian", vodeopt);
+  octave_value vjac = vodeopt.contents ("Jacobian");
   octave_idx_type vmebdfijac = 22; // We need to set this if no Jac available
   if (!vjac.is_empty ()) {
     vmebdfijacfun = vjac; vmebdfijac = 21;
@@ -562,42 +563,44 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 
   // The option Mass will be ignored by this solver. We can't handle
   // Mass-matrix options with IDE problems
-  octave_value vmass = odepkg_auxiliary_getmapvalue ("Mass", vodeopt);
+  octave_value vmass = vodeopt.contents ("Mass");
   if (!vmass.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
       "Option \"Mass\" will be ignored by this solver");
 
   // The option MStateDependence will be ignored by this solver. We
   // can't handle Mass-matrix options with IDE problems
-  octave_value vmst = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
-  if (!vmst.is_empty () && (vmst.string_value ().compare ("weak") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"MStateDependence\" will be ignored by this solver");
+  octave_value vmst = vodeopt.contents ("MStateDependence");
+  if (!vmst.is_empty ())
+    if (vmst.string_value ().compare ("weak") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MStateDependence\" will be ignored by this solver");
 
   // The option MvPattern will be ignored by this solver. We
   // can't handle Mass-matrix options with IDE problems
-  octave_value vmvpat = odepkg_auxiliary_getmapvalue ("MvPattern", vodeopt);
+  octave_value vmvpat = vodeopt.contents ("MvPattern");
   if (!vmvpat.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
       "Option \"MvPattern\" will be ignored by this solver");
 
   // The option MvPattern will be ignored by this solver. We
   // can't handle Mass-matrix options with IDE problems
-  octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
-  if (!vmsing.is_empty () && (vmsing.string_value ().compare ("maybe") != 0))
-    warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"MassSingular\" will be ignored by this solver");
+  octave_value vmsing = vodeopt.contents ("MassSingular");
+  if (!vmsing.is_empty ())
+    if (vmsing.string_value ().compare ("maybe") != 0)
+      warning_with_id ("OdePkg:InvalidOption",
+        "Option \"MassSingular\" will be ignored by this solver");
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vinitslope = odepkg_auxiliary_getmapvalue ("InitialSlope", vodeopt);
+  octave_value vinitslope = vodeopt.contents ("InitialSlope");
   if (!vinitslope.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
       "Option \"InitialSlope\" will be ignored by this solver");
 
   // Implementation of the option MaxOrder has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vmaxder = odepkg_auxiliary_getmapvalue ("MaxOrder", vodeopt);
+  octave_value vmaxder = vodeopt.contents ("MaxOrder");
   if (vmaxder.is_empty ()) {
     vmaxder = 3;
     warning_with_id ("OdePkg:InvalidOption", 
@@ -612,12 +615,24 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   }
 
   // The option BDF will be ignored because this is a BDF solver
-  octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
-  if (vbdf.string_value () != "on") {
-    vbdf = "on";
+  octave_value vbdf = vodeopt.contents ("BDF");
+  if (vbdf.is_string ())
+    if (vbdf.string_value () != "on") {
+      vbdf = "on"; warning_with_id ("OdePkg:InvalidOption", 
+        "Option \"BDF\" set \"off\", new value \"on\" is used");
+    }
+  // The option NewtonTol and MaxNewtonIterations will be ignored by
+  // this solver, IT NEEDS TO BE CHECKED IF THE FORTRAN CORE SOLVER
+  // CAN HANDLE THESE OPTIONS
+  octave_value vntol = vodeopt.contents ("NewtonTol");
+  if (!vntol.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
-      "Option \"BDF\" set \"off\", new value \"on\" is used");
-  }
+      "Option \"NewtonTol\" will be ignored by this solver");
+  octave_value vmaxnewton = 
+    vodeopt.contents ("MaxNewtonIterations");
+  if (!vmaxnewton.is_empty ())
+    warning_with_id ("OdePkg:InvalidOption", 
+      "Option \"MaxNewtonIterations\" will be ignored by this solver");
 
 /* Start MAINPROCESSING, set up all variables that are needed by this
  * solver and then initialize the solver function and get into the
@@ -663,7 +678,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // Check if the user has set some of the options "OutputFcn", "Events"
   // etc. and initialize the plot, events and the solstore functions
   octave_value vtim (T0); octave_value vsol (vY0); octave_value vyds (vYPRIME);
-  odepkg_auxiliary_solstore (vtim, vsol, voutsel, 0);
+  odepkg_auxiliary_solstore (vtim, vsol, 0);
   if (!vplot.is_empty ()) odepkg_auxiliary_evalplotfun 
     (vplot, voutsel, args(1), args(2), vmebdfiextarg, 0);
 
@@ -744,7 +759,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
           return (vretval);
         }
       }
-      odepkg_auxiliary_solstore (vtim, vsol, voutsel, 1);
+      odepkg_auxiliary_solstore (vtim, vsol, 1);
     }
   }
   else { // if (vTIME.length () > 2) we have all the time values needed
@@ -795,7 +810,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
           return (vretval);
         }
       }
-     odepkg_auxiliary_solstore (vtim, vsol, voutsel, 1);
+     odepkg_auxiliary_solstore (vtim, vsol, 1);
     }
   }
 
@@ -820,10 +835,10 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // Return the results that have been stored in the
   // odepkg_auxiliary_solstore function
   octave_value vtres, vyres;
-  odepkg_auxiliary_solstore (vtres, vyres, voutsel, 2);
+  odepkg_auxiliary_solstore (vtres, vyres, 2);
   // odepkg_auxiliary_solstore (vtres, vyres, voutsel, 100);
 
-  // Get the stats information as an Octave_map if the option 'Stats'
+  // Get the stats information as an octave_scalar_map if the option 'Stats'
   // has been set with odeset
   octave_value_list vstatinput;
   vstatinput(0) = IWORK[4];
@@ -842,7 +857,7 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
   // Set up output arguments that depends on how many output arguments
   // are desired by the caller
   if (nargout == 1) {
-    Octave_map vretmap;
+    octave_scalar_map vretmap;
     vretmap.assign ("x", vtres);
     vretmap.assign ("y", vyres);
     vretmap.assign ("solver", "odebdi");
@@ -1022,7 +1037,15 @@ odebdi (@@odepkg_equations_ilorenz, [0, 25], [3 15 1], \\\n\
 %!  vsol = odebdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
 %!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
 %!test %# BDF option
-%!  vopt = odeset ('BDF', 'on');
+%!  vopt = odeset ('BDF', 'off');
+%!  vsol = odebdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set NewtonTol option to something else than default
+%!  vopt = odeset ('NewtonTol', 1e-3);
+%!  vsol = odebdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
+%!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
+%!test %# Set MaxNewtonIterations option to something else than default
+%!  vopt = odeset ('MaxNewtonIterations', 2);
 %!  vsol = odebdi (@fpol, [0, 2], [2; 0], [0; -2], vopt);
 %!  assert ([vsol.x(end), vsol.y(end,:)], [2, fref], 1e-3);
 %!
