@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2007-2009, Thomas Treichl <treichl@users.sourceforge.net>
+Copyright (C) 2007-2012, Thomas Treichl <treichl@users.sourceforge.net>
 OdePkg - A package for solving ordinary differential equations and more
 
 This program is free software; you can redistribute it and/or modify
@@ -277,7 +277,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   octave_idx_type nargin = args.length (); // The number of input arguments
   octave_value_list vretval;               // The cell array of return args
-  Octave_map vodeopt;                      // The OdePkg options structure
+  octave_scalar_map vodeopt;               // The OdePkg options structure
 
   // Check number and types of all input arguments
   if (nargin < 3) {
@@ -319,7 +319,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
     // Fourth input argument != OdePkg option, need a default structure
     if (!args(3).is_map ()) {
       octave_value_list tmp = feval ("odeset", tmp, 1);
-      vodeopt = tmp(0).map_value ();       // Create a default structure
+      vodeopt = tmp(0).scalar_map_value ();       // Create a default structure
       for (octave_idx_type vcnt = 3; vcnt < nargin; vcnt++)
         vradau5extarg(vcnt-3) = args(vcnt); // Save arguments in vradau5extarg
     }
@@ -330,7 +330,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
       varin(0) = args(3); varin(1) = "ode5r";
       octave_value_list tmp = feval ("odepkg_structure_check", varin, 1);
       if (error_state) return (vretval);
-      vodeopt = tmp(0).map_value ();       // Create structure from args(4)
+      vodeopt = tmp(0).scalar_map_value ();       // Create structure from args(4)
       for (octave_idx_type vcnt = 4; vcnt < nargin; vcnt++)
         vradau5extarg(vcnt-4) = args(vcnt); // Save extra arguments
     }
@@ -341,14 +341,14 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
       varin(0) = args(3); varin(1) = "ode5r"; // Check structure
       octave_value_list tmp = feval ("odepkg_structure_check", varin, 1);
       if (error_state) return (vretval);
-      vodeopt = tmp(0).map_value (); // Create a default structure
+      vodeopt = tmp(0).scalar_map_value (); // Create a default structure
     }
 
   } // if (nargin >= 4)
 
   else { // if nargin == 3, everything else has been checked before
     octave_value_list tmp = feval ("odeset", tmp, 1);
-    vodeopt = tmp(0).map_value (); // Create a default structure
+    vodeopt = tmp(0).scalar_map_value (); // Create a default structure
   }
 
 /* Start PREPROCESSING, ie. check which options have been set and
@@ -358,7 +358,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option RelTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vreltol = odepkg_auxiliary_getmapvalue ("RelTol", vodeopt);
+  octave_value vreltol = vodeopt.contents ("RelTol");
   if (vreltol.is_empty ()) {
     vreltol = 1.0e-6;
     warning_with_id ("OdePkg:InvalidOption",
@@ -375,7 +375,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option AbsTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vabstol = odepkg_auxiliary_getmapvalue ("AbsTol", vodeopt);
+  octave_value vabstol = vodeopt.contents ("AbsTol");
   if (vabstol.is_empty ()) {
     vabstol = 1.0e-6;
     warning_with_id ("OdePkg:InvalidOption",
@@ -405,7 +405,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
+  octave_value vnorm = vodeopt.contents ("NormControl");
   if (!vnorm.is_empty ())
     if (vnorm.string_value ().compare ("off") != 0)
       warning_with_id ("OdePkg:InvalidOption",
@@ -413,31 +413,31 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vnneg = odepkg_auxiliary_getmapvalue ("NonNegative", vodeopt);
+  octave_value vnneg = vodeopt.contents ("NonNegative");
   if (!vnneg.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"NonNegative\" will be ignored by this solver");
 
   // Implementation of the option OutputFcn has been finished, this
   // option can be set by the user to another value than default value
-  vradau5pltfun = odepkg_auxiliary_getmapvalue ("OutputFcn", vodeopt);
+  vradau5pltfun = vodeopt.contents ("OutputFcn");
   if (vradau5pltfun.is_empty () && nargout == 0) vradau5pltfun = "odeplot";
 
   // Implementation of the option OutputSel has been finished, this
   // option can be set by the user to another value than default value
-  vradau5outsel = odepkg_auxiliary_getmapvalue ("OutputSel", vodeopt);
+  vradau5outsel = vodeopt.contents ("OutputSel");
 
   // Implementation of the option OutputSel has been finished, this
   // option can be set by the user to another value than default value
-  vradau5refine = odepkg_auxiliary_getmapvalue ("Refine", vodeopt);
+  vradau5refine = vodeopt.contents ("Refine");
 
   // Implementation of the option Stats has been finished, this option
   // can be set by the user to another value than default value
-  octave_value vstats = odepkg_auxiliary_getmapvalue ("Stats", vodeopt);
+  octave_value vstats = vodeopt.contents ("Stats");
 
   // Implementation of the option InitialStep has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vinitstep = odepkg_auxiliary_getmapvalue ("InitialStep", vodeopt);
+  octave_value vinitstep = vodeopt.contents ("InitialStep");
   if (args(1).length () > 2) {
     error_with_id ("OdePkg:InvalidOption",
       "Fixed time stamps are not supported by this solver");
@@ -451,7 +451,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option MaxStep has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vmaxstep = odepkg_auxiliary_getmapvalue ("MaxStep", vodeopt);
+  octave_value vmaxstep = vodeopt.contents ("MaxStep");
   if (vmaxstep.is_empty () && args(1).length () == 2) {
     vmaxstep = (args(1).vector_value ()(1) - args(1).vector_value ()(0)) / 12.5;
     warning_with_id ("OdePkg:InvalidOption",
@@ -462,24 +462,24 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Implementation of the option Events has been finished, this
   // option can be set by the user to another value than default
   // value, odepkg_structure_check already checks for a valid value
-  vradau5evefun = odepkg_auxiliary_getmapvalue ("Events", vodeopt);
+  vradau5evefun = vodeopt.contents ("Events");
 
   // Implementation of the option 'Jacobian' has been finished, these
   // options can be set by the user to another value than default
-  vradau5jacfun = odepkg_auxiliary_getmapvalue ("Jacobian", vodeopt);
+  vradau5jacfun = vodeopt.contents ("Jacobian");
   octave_idx_type vradau5jac = 0; // We need to set this if no Jac available
   if (!vradau5jacfun.is_empty ()) vradau5jac = 1;
 
   // The option JPattern will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vradau5jacpat = odepkg_auxiliary_getmapvalue ("JPattern", vodeopt);
+  octave_value vradau5jacpat = vodeopt.contents ("JPattern");
   if (!vradau5jacpat.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"JPattern\" will be ignored by this solver");
 
   // The option Vectorized will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vradau5vectorize = odepkg_auxiliary_getmapvalue ("Vectorized", vodeopt);
+  octave_value vradau5vectorize = vodeopt.contents ("Vectorized");
   if (!vradau5vectorize.is_empty ())
     if (vradau5vectorize.string_value ().compare ("off") != 0)
       warning_with_id ("OdePkg:InvalidOption",
@@ -487,7 +487,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option 'Mass' has been finished, these
   // options can be set by the user to another value than default
-  vradau5mass = odepkg_auxiliary_getmapvalue ("Mass", vodeopt);
+  vradau5mass = vodeopt.contents ("Mass");
   octave_idx_type vradau5mas = 0;
   if (!vradau5mass.is_empty ()) {
     vradau5mas = 1;
@@ -498,7 +498,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
-  vradau5massstate = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
+  vradau5massstate = vodeopt.contents ("MStateDependence");
   if (!vradau5massstate.is_empty ())
     if (vradau5massstate.string_value ().compare ("weak") != 0) // 'weak' is default
       warning_with_id ("OdePkg:InvalidOption",
@@ -506,14 +506,14 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
-  octave_value vmvpat = odepkg_auxiliary_getmapvalue ("MvPattern", vodeopt);
+  octave_value vmvpat = vodeopt.contents ("MvPattern");
   if (!vmvpat.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"MvPattern\" will be ignored by this solver");
 
   // The option MassSingular will be ignored by this solver, the
   // core Fortran solver doesn't support this option
-  octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
+  octave_value vmsing = vodeopt.contents ("MassSingular");
   if (!vmsing.is_empty ())
     if (vmsing.string_value ().compare ("maybe") != 0)
       warning_with_id ("OdePkg:InvalidOption",
@@ -521,21 +521,21 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vinitslope = odepkg_auxiliary_getmapvalue ("InitialSlope", vodeopt);
+  octave_value vinitslope = vodeopt.contents ("InitialSlope");
   if (!vinitslope.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"InitialSlope\" will be ignored by this solver");
 
   // The option MaxOrder will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vmaxder = odepkg_auxiliary_getmapvalue ("MaxOrder", vodeopt);
+  octave_value vmaxder = vodeopt.contents ("MaxOrder");
   if (!vmaxder.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"MaxOrder\" will be ignored by this solver");
 
   // The option BDF will be ignored by this solver, the core Fortran
   // solver doesn't support this option
-  octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
+  octave_value vbdf = vodeopt.contents ("BDF");
   if (!vbdf.is_empty ())
     if (vbdf.string_value ().compare ("off") != 0)
       warning_with_id ("OdePkg:InvalidOption", 
@@ -543,7 +543,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option NewtonTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vNTOL = odepkg_auxiliary_getmapvalue ("NewtonTol", vodeopt);
+  octave_value vNTOL = vodeopt.contents ("NewtonTol");
   if (vNTOL.is_empty ()) {
     vNTOL = 0;
     warning_with_id ("OdePkg:InvalidOption", 
@@ -553,7 +553,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Implementation of the option MaxNewtonIterations has been finished, this
   // option can be set by the user to another value than default value
   octave_value vmaxnit = 
-    odepkg_auxiliary_getmapvalue ("MaxNewtonIterations", vodeopt);
+    vodeopt.contents ("MaxNewtonIterations");
   if (vmaxnit.is_empty ()) {
     vmaxnit = 7; warning_with_id ("OdePkg:InvalidOption", 
       "Option \"MaxNewtonIterations\" not set, default value 7 is used");
@@ -653,7 +653,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   if (!vradau5evefun.is_empty ()) odepkg_auxiliary_evaleventfun
     (vradau5evefun, vted, vfin, vradau5extarg, 2);
   
-  // Get the stats information as an Octave_map if the option 'Stats'
+  // Get the stats information as an octave_scalar_map if the option 'Stats'
   // has been set with odeset
   // "nsteps", "nfailed", "nfevals", "npds", "ndecomps", "nlinsols"
   octave_value_list vstatinput;
@@ -672,7 +672,7 @@ ode5r (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Set up output arguments that depend on how many output arguments
   // are desired from the caller
   if (nargout == 1) {
-    Octave_map vretmap;
+    octave_scalar_map vretmap;
     vretmap.assign ("x", vtres);
     vretmap.assign ("y", vyres);
     vretmap.assign ("solver", "ode5r");
