@@ -461,7 +461,7 @@ octave_idx_type odepkg_rodas_dfxfcn
 // PKG_ADD: autoload ("oders",  "dldsolver.oct");
 DEFUN_DLD (oders, args, nargout, 
 "-*- texinfo -*-\n\
-@deftypefn  {Function File} {[@var{}] =} oders (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
+@deftypefn  {Loadable Function} {[@var{}] =} oders (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 @deftypefnx {Command} {[@var{sol}] =} oders (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 @deftypefnx {Command} {[@var{t}, @var{y}, [@var{xe}, @var{ye}, @var{ie}]] =} oders (@var{@@fun}, @var{slot}, @var{init}, [@var{opt}], [@var{par1}, @var{par2}, @dots{}])\n\
 \n\
@@ -491,7 +491,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   octave_idx_type nargin = args.length (); // The number of input arguments
   octave_value_list vretval;               // The cell array of return args
-  Octave_map vodeopt;                      // The OdePkg options structure
+  octave_scalar_map vodeopt;                      // The OdePkg options structure
 
   // Check number and types of all input arguments
   if (nargin < 3) {
@@ -533,7 +533,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
     // Fourth input argument != OdePkg option, need a default structure
     if (!args(3).is_map ()) {
       octave_value_list tmp = feval ("odeset", tmp, 1);
-      vodeopt = tmp(0).map_value ();       // Create a default structure
+      vodeopt = tmp(0).scalar_map_value ();       // Create a default structure
       for (octave_idx_type vcnt = 3; vcnt < nargin; vcnt++)
         vrodasextarg(vcnt-3) = args(vcnt); // Save arguments in vrodasextarg
     }
@@ -544,7 +544,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
       varin(0) = args(3); varin(1) = "oders";
       octave_value_list tmp = feval ("odepkg_structure_check", varin, 1);
       if (error_state) return (vretval);
-      vodeopt = tmp(0).map_value ();       // Create structure from args(4)
+      vodeopt = tmp(0).scalar_map_value ();       // Create structure from args(4)
       for (octave_idx_type vcnt = 4; vcnt < nargin; vcnt++)
         vrodasextarg(vcnt-4) = args(vcnt); // Save extra arguments
     }
@@ -555,14 +555,14 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
       varin(0) = args(3); varin(1) = "oders"; // Check structure
       octave_value_list tmp = feval ("odepkg_structure_check", varin, 1);
       if (error_state) return (vretval);
-      vodeopt = tmp(0).map_value (); // Create a default structure
+      vodeopt = tmp(0).scalar_map_value (); // Create a default structure
     }
 
   } // if (nargin >= 4)
 
   else { // if nargin == 3, everything else has been checked before
     octave_value_list tmp = feval ("odeset", tmp, 1);
-    vodeopt = tmp(0).map_value (); // Create a default structure
+    vodeopt = tmp(0).scalar_map_value (); // Create a default structure
   }
 
 /* Start PREPROCESSING, ie. check which options have been set and
@@ -572,7 +572,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option RelTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vreltol = odepkg_auxiliary_getmapvalue ("RelTol", vodeopt);
+  octave_value vreltol = vodeopt.contents ("RelTol");
   if (vreltol.is_empty ()) {
     vreltol = 1.0e-6;
     warning_with_id ("OdePkg:InvalidOption",
@@ -589,7 +589,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option AbsTol has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vabstol = odepkg_auxiliary_getmapvalue ("AbsTol", vodeopt);
+  octave_value vabstol = vodeopt.contents ("AbsTol");
   if (vabstol.is_empty ()) {
     vabstol = 1.0e-6;
     warning_with_id ("OdePkg:InvalidOption",
@@ -619,7 +619,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option NormControl will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vnorm = odepkg_auxiliary_getmapvalue ("NormControl", vodeopt);
+  octave_value vnorm = vodeopt.contents ("NormControl");
   if (!vnorm.is_empty ())
     if (vnorm.string_value ().compare ("off") != 0)
       warning_with_id ("OdePkg:InvalidOption",
@@ -627,31 +627,31 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option NonNegative will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vnneg = odepkg_auxiliary_getmapvalue ("NonNegative", vodeopt);
+  octave_value vnneg = vodeopt.contents ("NonNegative");
   if (!vnneg.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"NonNegative\" will be ignored by this solver");
 
   // Implementation of the option OutputFcn has been finished, this
   // option can be set by the user to another value than default value
-  vrodaspltfun = odepkg_auxiliary_getmapvalue ("OutputFcn", vodeopt);
+  vrodaspltfun = vodeopt.contents ("OutputFcn");
   if (vrodaspltfun.is_empty () && nargout == 0) vrodaspltfun = "odeplot";
 
   // Implementation of the option OutputSel has been finished, this
   // option can be set by the user to another value than default value
-  vrodasoutsel = odepkg_auxiliary_getmapvalue ("OutputSel", vodeopt);
+  vrodasoutsel = vodeopt.contents ("OutputSel");
 
   // Implementation of the option OutputSel has been finished, this
   // option can be set by the user to another value than default value
-  vrodasrefine = odepkg_auxiliary_getmapvalue ("Refine", vodeopt);
+  vrodasrefine = vodeopt.contents ("Refine");
 
   // Implementation of the option Stats has been finished, this option
   // can be set by the user to another value than default value
-  octave_value vstats = odepkg_auxiliary_getmapvalue ("Stats", vodeopt);
+  octave_value vstats = vodeopt.contents ("Stats");
 
   // Implementation of the option InitialStep has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vinitstep = odepkg_auxiliary_getmapvalue ("InitialStep", vodeopt);
+  octave_value vinitstep = vodeopt.contents ("InitialStep");
   if (args(1).length () > 2) {
     error_with_id ("OdePkg:InvalidOption",
       "Fixed time stamps are not supported by this solver");
@@ -665,7 +665,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option MaxStep has been finished, this
   // option can be set by the user to another value than default value
-  octave_value vmaxstep = odepkg_auxiliary_getmapvalue ("MaxStep", vodeopt);
+  octave_value vmaxstep = vodeopt.contents ("MaxStep");
   if (vmaxstep.is_empty () && args(1).length () == 2) {
     vmaxstep = (args(1).vector_value ()(1) - args(1).vector_value ()(0)) / 12.5;
     warning_with_id ("OdePkg:InvalidOption",
@@ -676,24 +676,24 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Implementation of the option Events has been finished, this
   // option can be set by the user to another value than default
   // value, odepkg_structure_check already checks for a valid value
-  vrodasevefun = odepkg_auxiliary_getmapvalue ("Events", vodeopt);
+  vrodasevefun = vodeopt.contents ("Events");
 
   // Implementation of the option 'Jacobian' has been finished, these
   // options can be set by the user to another value than default
-  vrodasjacfun = odepkg_auxiliary_getmapvalue ("Jacobian", vodeopt);
+  vrodasjacfun = vodeopt.contents ("Jacobian");
   octave_idx_type vrodasjac = 0; // We need to set this if no Jac available
   if (!vrodasjacfun.is_empty ()) vrodasjac = 1;
 
   // The option JPattern will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vrodasjacpat = odepkg_auxiliary_getmapvalue ("JPattern", vodeopt);
+  octave_value vrodasjacpat = vodeopt.contents ("JPattern");
   if (!vrodasjacpat.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"JPattern\" will be ignored by this solver");
 
   // The option Vectorized will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vrodasvectorize = odepkg_auxiliary_getmapvalue ("Vectorized", vodeopt);
+  octave_value vrodasvectorize = vodeopt.contents ("Vectorized");
   if (!vrodasvectorize.is_empty ())
     if (vrodasvectorize.string_value ().compare ("off") != 0)
       warning_with_id ("OdePkg:InvalidOption",
@@ -701,7 +701,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // Implementation of the option 'Mass' has been finished, these
   // options can be set by the user to another value than default
-  vrodasmass = odepkg_auxiliary_getmapvalue ("Mass", vodeopt);
+  vrodasmass = vodeopt.contents ("Mass");
   octave_idx_type vrodasmas = 0;
   if (!vrodasmass.is_empty ()) {
     vrodasmas = 1;
@@ -712,7 +712,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
-  vrodasmassstate = odepkg_auxiliary_getmapvalue ("MStateDependence", vodeopt);
+  vrodasmassstate = vodeopt.contents ("MStateDependence");
   if (!vrodasmassstate.is_empty ())
     if (vrodasmassstate.string_value ().compare ("weak") != 0) // 'weak' is default
       warning_with_id ("OdePkg:InvalidOption",
@@ -720,14 +720,14 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option MStateDependence will be ignored by this solver, the
   // core Fortran solver doesn't support this option
-  octave_value vmvpat = odepkg_auxiliary_getmapvalue ("MvPattern", vodeopt);
+  octave_value vmvpat = vodeopt.contents ("MvPattern");
   if (!vmvpat.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"MvPattern\" will be ignored by this solver");
 
   // The option MassSingular will be ignored by this solver, the
   // core Fortran solver doesn't support this option
-  octave_value vmsing = odepkg_auxiliary_getmapvalue ("MassSingular", vodeopt);
+  octave_value vmsing = vodeopt.contents ("MassSingular");
   if (!vmsing.is_empty ())
     if (vmsing.string_value ().compare ("maybe") != 0)
       warning_with_id ("OdePkg:InvalidOption",
@@ -735,21 +735,21 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
 
   // The option InitialSlope will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vinitslope = odepkg_auxiliary_getmapvalue ("InitialSlope", vodeopt);
+  octave_value vinitslope = vodeopt.contents ("InitialSlope");
   if (!vinitslope.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"InitialSlope\" will be ignored by this solver");
 
   // The option MaxOrder will be ignored by this solver, the core
   // Fortran solver doesn't support this option
-  octave_value vmaxder = odepkg_auxiliary_getmapvalue ("MaxOrder", vodeopt);
+  octave_value vmaxder = vodeopt.contents ("MaxOrder");
   if (!vmaxder.is_empty ())
     warning_with_id ("OdePkg:InvalidOption",
       "Option \"MaxOrder\" will be ignored by this solver");
 
   // The option BDF will be ignored by this solver, the core Fortran
   // solver doesn't support this option
-  octave_value vbdf = odepkg_auxiliary_getmapvalue ("BDF", vodeopt);
+  octave_value vbdf = vodeopt.contents ("BDF");
   if (!vbdf.is_empty ())
     if (vbdf.string_value ().compare ("off") != 0)
       warning_with_id ("OdePkg:InvalidOption", 
@@ -757,12 +757,12 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // The option NewtonTol and MaxNewtonIterations will be ignored by
   // this solver, IT NEEDS TO BE CHECKED IF THE FORTRAN CORE SOLVER
   // CAN HANDLE THESE OPTIONS
-  octave_value vntol = odepkg_auxiliary_getmapvalue ("NewtonTol", vodeopt);
+  octave_value vntol = vodeopt.contents ("NewtonTol");
   if (!vntol.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
       "Option \"NewtonTol\" will be ignored by this solver");
   octave_value vmaxnewton = 
-    odepkg_auxiliary_getmapvalue ("MaxNewtonIterations", vodeopt);
+    vodeopt.contents ("MaxNewtonIterations");
   if (!vmaxnewton.is_empty ())
     warning_with_id ("OdePkg:InvalidOption", 
       "Option \"MaxNewtonIterations\" will be ignored by this solver");
@@ -854,7 +854,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   if (!vrodasevefun.is_empty ()) odepkg_auxiliary_evaleventfun
     (vrodasevefun, vted, vfin, vrodasextarg, 2);
   
-  // Get the stats information as an Octave_map if the option 'Stats'
+  // Get the stats information as an octave_scalar_map if the option 'Stats'
   // has been set with odeset
   octave_value_list vstatinput;
   vstatinput(0) = IWORK[16];
@@ -872,7 +872,7 @@ oders (@@odepkg_equations_lorenz, [0, 25], [3 15 1], vopt);\n\
   // Set up output arguments that depend on how many output arguments
   // are desired from the caller
   if (nargout == 1) {
-    Octave_map vretmap;
+    octave_scalar_map vretmap;
     vretmap.assign ("x", vtres);
     vretmap.assign ("y", vyres);
     vretmap.assign ("solver", "oders");
